pub struct StringParameter {
pub(crate) name: CapeStringImpl,
description: CapeStringImpl,
is_input: bool,
shared_unit_data: Rc<RefCell<SharedUnitData>>,
pub(crate) value: CapeStringImpl,
default_value: CapeStringImpl,
possible_values: Option<CapeArrayStringVec>,
exclusive: bool,
validation_status: CapeValidationStatus,
cobia_object_data: StringParameterCobiaObjectData,
}Expand description
The StringParameter class implements a CAPE-OPEN 1.2 string parameter.
Parameters must implement the ICapeIdentification and ICapeParameter interfaces. In addition, string parameters must implement the ICapeStringParameter interface.
This implementation can be used for both input and output parameters. Input parameters can be set by the user, while output parameters are set by the unit operation.
Fields
name: CapeStringImplThe name of the parameter
description: CapeStringImplThe description of the parameter
is_input: boolIndicates whether this parameter is an input (true) or an output (false)
Shared data for the unit, containing unit-specific information
value: CapeStringImplThe current value of the parameter
default_value: CapeStringImplDefault value of the parameter
possible_values: Option<CapeArrayStringVec>List of allowed values for the parameter
exclusive: boolExclusive implies only values in the list are allowed.
validation_status: CapeValidationStatusValidation status of the parameter
cobia_object_data: StringParameterCobiaObjectDataCobia object data for this object, which contains generated code to provide the native COBIA interfaces
Implementations
Sourceimpl StringParameter
impl StringParameter
fn create_instance( _string_parameter_boxed_ptr: *mut *mut ICapeInterface, name: CapeStringImpl, description: CapeStringImpl, is_input: bool, shared_unit_data: Rc<RefCell<SharedUnitData>>, default_value: CapeStringImpl, possible_values: Option<CapeArrayStringVec>, exclusive: bool, ) -> CapeResult
Sourcepub(crate) fn create<T: CapeSmartPointer>(
name: CapeStringImpl,
description: CapeStringImpl,
is_input: bool,
shared_unit_data: Rc<RefCell<SharedUnitData>>,
default_value: CapeStringImpl,
possible_values: Option<CapeArrayStringVec>,
exclusive: bool,
) -> T
pub(crate) fn create<T: CapeSmartPointer>( name: CapeStringImpl, description: CapeStringImpl, is_input: bool, shared_unit_data: Rc<RefCell<SharedUnitData>>, default_value: CapeStringImpl, possible_values: Option<CapeArrayStringVec>, exclusive: bool, ) -> T
Create a new instance of the object and return a smart pointer to it
This function panics if the created object does not implement the interface corresponding to the smart pointer to be returned. For a non-panic version, use the try_create() function.
Sourcepub(crate) fn try_create<T: CapeSmartPointer>(
name: CapeStringImpl,
description: CapeStringImpl,
is_input: bool,
shared_unit_data: Rc<RefCell<SharedUnitData>>,
default_value: CapeStringImpl,
possible_values: Option<CapeArrayStringVec>,
exclusive: bool,
) -> Result<T, COBIAError>
pub(crate) fn try_create<T: CapeSmartPointer>( name: CapeStringImpl, description: CapeStringImpl, is_input: bool, shared_unit_data: Rc<RefCell<SharedUnitData>>, default_value: CapeStringImpl, possible_values: Option<CapeArrayStringVec>, exclusive: bool, ) -> Result<T, COBIAError>
Create a new instance of the object and return a smart pointer to it
This function returns an error if the created object does not implement the interface corresponding to the smart pointer to be returned.
Sourcepub(crate) unsafe fn borrow<T: CapeSmartPointer>(smart_pointer: &T) -> &Self
pub(crate) unsafe fn borrow<T: CapeSmartPointer>(smart_pointer: &T) -> &Self
Get a reference to the object
Note that as the reference is created from a smart pointer, the reference is valid only as long as the smart pointer is valid. The reference is not checked for multiple borrows
Safety
The user must ensure that the smart pointer contains a valid object, and that the object is of the type that is being borrowed. It is not possible for the compiler to check this, as the borrow is done through the native object pointer in the interface.
Sourcepub(crate) unsafe fn borrow_mut<T: CapeSmartPointer>(
smart_pointer: &mut T,
) -> &mut Self
pub(crate) unsafe fn borrow_mut<T: CapeSmartPointer>( smart_pointer: &mut T, ) -> &mut Self
Get a mutable reference to the object
Note that as the reference is created from a smart pointer, the reference is valid only as long as the smart pointer is valid. The reference is not checked for multiple borrows
Safety
This function is unsafe because it allows mutable access to the object. Also the user must ensure that the smart pointer contains a valid object, and that the object is of the type that is being borrowed. It is not possible for the compiler to check this, as the borrow is done through the native object pointer in the interface.
Sourceimpl StringParameter
impl StringParameter
pub fn new( name: CapeStringImpl, description: CapeStringImpl, is_input: bool, shared_unit_data: Rc<RefCell<SharedUnitData>>, default_value: CapeStringImpl, possible_values: Option<CapeArrayStringVec>, exclusive: bool, ) -> Self
Sourcepub fn set_possible_values(
&mut self,
possible_values: Option<&CapeArrayStringVec>,
)
pub fn set_possible_values( &mut self, possible_values: Option<&CapeArrayStringVec>, )
Replace the list of possible values with a new list.
Arguments:
possible_values- AnOption<CapeArrayStringVec>containing the new list of possible values. IfNone, the parameter will not have any possible values.